Documentation
¶
Overview ¶
ui :)
Index ¶
- Constants
- func Button(pos core.Vec2, size core.Vec2, text string, style ButtonStyle, ...)
- func CycleButton(pos core.Vec2, size core.Vec2, current *int, options ...string)
- func DrawBoldText(text string, pos core.Vec2, fontSize int, color core.Color)
- func DrawDangerButton(pos core.Vec2, size core.Vec2)
- func DrawDialog(pos core.Vec2, size core.Vec2)
- func DrawHoverOutline(pos core.Vec2, size core.Vec2)
- func DrawItalicText(text string, pos core.Vec2, fontSize int, color core.Color)
- func DrawPressedButton(pos core.Vec2, size core.Vec2)
- func DrawPrimaryButton(pos core.Vec2, size core.Vec2)
- func DrawRegularText(text string, pos core.Vec2, fontSize int, color core.Color)
- func DrawSecondaryButton(pos core.Vec2, size core.Vec2)
- func DrawSlider(pos core.Vec2, size core.Vec2, grabber float64)
- func DrawTextInput(pos core.Vec2, size core.Vec2)
- func FreeTheme()
- func LoadTheme()
- func Slider(pos core.Vec2, size core.Vec2, label string, min float64, max float64, ...)
- func TextInput(pos core.Vec2, size core.Vec2, placeholder string, out *string)
- func ToggleButton(pos core.Vec2, size core.Vec2, text string, out *bool)
- type ButtonStyle
Constants ¶
const ButtonHeight float64 = 40
yeah
const DefaultFontSize int = 26
yeah
const Separation int = 8
yeah
Variables ¶
This section is empty.
Functions ¶
func CycleButton ¶
it's a button that cycles. writes the index into current
func DrawBoldText ¶
as the name implies, it draws bold text
func DrawDangerButton ¶
as the name implies, it draws a danger button
func DrawHoverOutline ¶
draw on top of a button/text input when it's focused
func DrawItalicText ¶
as the name implies, it draws italic text
func DrawPressedButton ¶
this is used for every button when pressed because i'm lazy
func DrawPrimaryButton ¶
as the name implies, it draws a primary button
func DrawRegularText ¶
as the name implies, it draws regular text
func DrawSecondaryButton ¶
as the name implies, it draws a secondary button
func DrawSlider ¶
slider. grabber is on a range from 0 to 1
func DrawTextInput ¶
as the name implies, it draws a text input
Types ¶
type ButtonStyle ¶
type ButtonStyle int
const ( ButtonStylePrimary ButtonStyle = iota ButtonStyleSecondary ButtonStyleDanger )
Click to show internal directories.
Click to hide internal directories.